mockservices

package
v0.0.0-...-bea2f44 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 7, 2025 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Overview

Package mockservices provides mock implementations of service interfaces for testing

Package mockservices is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CharacterServiceInterface

type CharacterServiceInterface interface {
	CreateCharacter(ctx context.Context, userID, name string) (string, error)
	GetCharacter(ctx context.Context, id string) (interface{}, error)
	MoveCharacter(ctx context.Context, characterID string, x, y int32) error
	ListCharacters(ctx context.Context, userID string) ([]interface{}, error)
}

CharacterServiceInterface represents a basic character service interface

type ChunkServiceInterface

type ChunkServiceInterface interface {
	GetChunk(ctx context.Context, worldID string, x, y int32) (interface{}, error)
	GenerateChunk(ctx context.Context, worldID string, x, y int32) (interface{}, error)
}

ChunkServiceInterface represents a basic chunk service interface

type MockCharacterServiceInterface

type MockCharacterServiceInterface struct {
	// contains filtered or unexported fields
}

MockCharacterServiceInterface is a mock of CharacterServiceInterface interface.

func NewMockCharacterServiceInterface

func NewMockCharacterServiceInterface(ctrl *gomock.Controller) *MockCharacterServiceInterface

NewMockCharacterServiceInterface creates a new mock instance.

func (*MockCharacterServiceInterface) CreateCharacter

func (m *MockCharacterServiceInterface) CreateCharacter(ctx context.Context, userID, name string) (string, error)

CreateCharacter mocks base method.

func (*MockCharacterServiceInterface) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockCharacterServiceInterface) GetCharacter

func (m *MockCharacterServiceInterface) GetCharacter(ctx context.Context, id string) (any, error)

GetCharacter mocks base method.

func (*MockCharacterServiceInterface) ListCharacters

func (m *MockCharacterServiceInterface) ListCharacters(ctx context.Context, userID string) ([]any, error)

ListCharacters mocks base method.

func (*MockCharacterServiceInterface) MoveCharacter

func (m *MockCharacterServiceInterface) MoveCharacter(ctx context.Context, characterID string, x, y int32) error

MoveCharacter mocks base method.

type MockCharacterServiceInterfaceMockRecorder

type MockCharacterServiceInterfaceMockRecorder struct {
	// contains filtered or unexported fields
}

MockCharacterServiceInterfaceMockRecorder is the mock recorder for MockCharacterServiceInterface.

func (*MockCharacterServiceInterfaceMockRecorder) CreateCharacter

func (mr *MockCharacterServiceInterfaceMockRecorder) CreateCharacter(ctx, userID, name any) *gomock.Call

CreateCharacter indicates an expected call of CreateCharacter.

func (*MockCharacterServiceInterfaceMockRecorder) GetCharacter

func (mr *MockCharacterServiceInterfaceMockRecorder) GetCharacter(ctx, id any) *gomock.Call

GetCharacter indicates an expected call of GetCharacter.

func (*MockCharacterServiceInterfaceMockRecorder) ListCharacters

func (mr *MockCharacterServiceInterfaceMockRecorder) ListCharacters(ctx, userID any) *gomock.Call

ListCharacters indicates an expected call of ListCharacters.

func (*MockCharacterServiceInterfaceMockRecorder) MoveCharacter

func (mr *MockCharacterServiceInterfaceMockRecorder) MoveCharacter(ctx, characterID, x, y any) *gomock.Call

MoveCharacter indicates an expected call of MoveCharacter.

type MockChunkServiceInterface

type MockChunkServiceInterface struct {
	// contains filtered or unexported fields
}

MockChunkServiceInterface is a mock of ChunkServiceInterface interface.

func NewMockChunkServiceInterface

func NewMockChunkServiceInterface(ctrl *gomock.Controller) *MockChunkServiceInterface

NewMockChunkServiceInterface creates a new mock instance.

func (*MockChunkServiceInterface) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockChunkServiceInterface) GenerateChunk

func (m *MockChunkServiceInterface) GenerateChunk(ctx context.Context, worldID string, x, y int32) (any, error)

GenerateChunk mocks base method.

func (*MockChunkServiceInterface) GetChunk

func (m *MockChunkServiceInterface) GetChunk(ctx context.Context, worldID string, x, y int32) (any, error)

GetChunk mocks base method.

type MockChunkServiceInterfaceMockRecorder

type MockChunkServiceInterfaceMockRecorder struct {
	// contains filtered or unexported fields
}

MockChunkServiceInterfaceMockRecorder is the mock recorder for MockChunkServiceInterface.

func (*MockChunkServiceInterfaceMockRecorder) GenerateChunk

func (mr *MockChunkServiceInterfaceMockRecorder) GenerateChunk(ctx, worldID, x, y any) *gomock.Call

GenerateChunk indicates an expected call of GenerateChunk.

func (*MockChunkServiceInterfaceMockRecorder) GetChunk

func (mr *MockChunkServiceInterfaceMockRecorder) GetChunk(ctx, worldID, x, y any) *gomock.Call

GetChunk indicates an expected call of GetChunk.

type MockWorldServiceInterface

type MockWorldServiceInterface struct {
	// contains filtered or unexported fields
}

MockWorldServiceInterface is a mock of WorldServiceInterface interface.

func NewMockWorldServiceInterface

func NewMockWorldServiceInterface(ctrl *gomock.Controller) *MockWorldServiceInterface

NewMockWorldServiceInterface creates a new mock instance.

func (*MockWorldServiceInterface) CreateWorld

func (m *MockWorldServiceInterface) CreateWorld(ctx context.Context, name string, seed int64) (string, error)

CreateWorld mocks base method.

func (*MockWorldServiceInterface) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockWorldServiceInterface) GetWorld

func (m *MockWorldServiceInterface) GetWorld(ctx context.Context, id string) (any, error)

GetWorld mocks base method.

type MockWorldServiceInterfaceMockRecorder

type MockWorldServiceInterfaceMockRecorder struct {
	// contains filtered or unexported fields
}

MockWorldServiceInterfaceMockRecorder is the mock recorder for MockWorldServiceInterface.

func (*MockWorldServiceInterfaceMockRecorder) CreateWorld

func (mr *MockWorldServiceInterfaceMockRecorder) CreateWorld(ctx, name, seed any) *gomock.Call

CreateWorld indicates an expected call of CreateWorld.

func (*MockWorldServiceInterfaceMockRecorder) GetWorld

func (mr *MockWorldServiceInterfaceMockRecorder) GetWorld(ctx, id any) *gomock.Call

GetWorld indicates an expected call of GetWorld.

type WorldServiceInterface

type WorldServiceInterface interface {
	CreateWorld(ctx context.Context, name string, seed int64) (string, error)
	GetWorld(ctx context.Context, id string) (interface{}, error)
}

WorldServiceInterface represents a basic world service interface

Jump to