terrain

package
v0.0.0-...-bea2f44 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 7, 2025 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DefaultLoggerWrapper

type DefaultLoggerWrapper struct{}

DefaultLoggerWrapper wraps the internal logging package.

func (*DefaultLoggerWrapper) Debug

func (l *DefaultLoggerWrapper) Debug(msg string, keysAndValues ...interface{})

func (*DefaultLoggerWrapper) Error

func (l *DefaultLoggerWrapper) Error(msg string, keysAndValues ...interface{})

func (*DefaultLoggerWrapper) Info

func (l *DefaultLoggerWrapper) Info(msg string, keysAndValues ...interface{})

func (*DefaultLoggerWrapper) Warn

func (l *DefaultLoggerWrapper) Warn(msg string, keysAndValues ...interface{})

func (*DefaultLoggerWrapper) With

func (l *DefaultLoggerWrapper) With(keysAndValues ...interface{}) LoggerInterface

type LoggerInterface

type LoggerInterface interface {
	Debug(msg string, keysAndValues ...interface{})
	Info(msg string, keysAndValues ...interface{})
	Warn(msg string, keysAndValues ...interface{})
	Error(msg string, keysAndValues ...interface{})
	With(keysAndValues ...interface{}) LoggerInterface
}

LoggerInterface abstracts logging operations for dependency injection.

func NewDefaultLoggerWrapper

func NewDefaultLoggerWrapper() LoggerInterface

NewDefaultLoggerWrapper creates a new default logger wrapper.

type Service

type Service struct {
	// contains filtered or unexported fields
}

Service provides terrain information and operations

func NewService

func NewService(logger LoggerInterface) *Service

NewService creates a new terrain service with dependency injection.

func NewServiceWithDefaultLogger

func NewServiceWithDefaultLogger() *Service

NewServiceWithDefaultLogger creates a service with the default logger (convenience constructor for production use).

func (*Service) GetTerrainTypes

func (s *Service) GetTerrainTypes(ctx context.Context) ([]*terrainV1.TerrainTypeInfo, error)

GetTerrainTypes returns all available terrain types with their properties

Jump to