Documentation
¶
Overview ¶
Package mockservices provides mock implementations of service interfaces for testing
Package mockservices is a generated GoMock package.
Index ¶
- type CharacterServiceInterface
- type ChunkServiceInterface
- type MockCharacterServiceInterface
- func (m *MockCharacterServiceInterface) CreateCharacter(ctx context.Context, userID, name string) (string, error)
- func (m *MockCharacterServiceInterface) EXPECT() *MockCharacterServiceInterfaceMockRecorder
- func (m *MockCharacterServiceInterface) GetCharacter(ctx context.Context, id string) (any, error)
- func (m *MockCharacterServiceInterface) ListCharacters(ctx context.Context, userID string) ([]any, error)
- func (m *MockCharacterServiceInterface) MoveCharacter(ctx context.Context, characterID string, x, y int32) error
- type MockCharacterServiceInterfaceMockRecorder
- func (mr *MockCharacterServiceInterfaceMockRecorder) CreateCharacter(ctx, userID, name any) *gomock.Call
- func (mr *MockCharacterServiceInterfaceMockRecorder) GetCharacter(ctx, id any) *gomock.Call
- func (mr *MockCharacterServiceInterfaceMockRecorder) ListCharacters(ctx, userID any) *gomock.Call
- func (mr *MockCharacterServiceInterfaceMockRecorder) MoveCharacter(ctx, characterID, x, y any) *gomock.Call
- type MockChunkServiceInterface
- func (m *MockChunkServiceInterface) EXPECT() *MockChunkServiceInterfaceMockRecorder
- func (m *MockChunkServiceInterface) GenerateChunk(ctx context.Context, worldID string, x, y int32) (any, error)
- func (m *MockChunkServiceInterface) GetChunk(ctx context.Context, worldID string, x, y int32) (any, error)
- type MockChunkServiceInterfaceMockRecorder
- type MockWorldServiceInterface
- type MockWorldServiceInterfaceMockRecorder
- type WorldServiceInterface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CharacterServiceInterface ¶
type CharacterServiceInterface interface {
CreateCharacter(ctx context.Context, userID, name string) (string, error)
GetCharacter(ctx context.Context, id string) (interface{}, error)
MoveCharacter(ctx context.Context, characterID string, x, y int32) error
ListCharacters(ctx context.Context, userID string) ([]interface{}, error)
}
CharacterServiceInterface represents a basic character service interface
type ChunkServiceInterface ¶
type ChunkServiceInterface interface {
GetChunk(ctx context.Context, worldID string, x, y int32) (interface{}, error)
GenerateChunk(ctx context.Context, worldID string, x, y int32) (interface{}, error)
}
ChunkServiceInterface represents a basic chunk service interface
type MockCharacterServiceInterface ¶
type MockCharacterServiceInterface struct {
// contains filtered or unexported fields
}
MockCharacterServiceInterface is a mock of CharacterServiceInterface interface.
func NewMockCharacterServiceInterface ¶
func NewMockCharacterServiceInterface(ctrl *gomock.Controller) *MockCharacterServiceInterface
NewMockCharacterServiceInterface creates a new mock instance.
func (*MockCharacterServiceInterface) CreateCharacter ¶
func (m *MockCharacterServiceInterface) CreateCharacter(ctx context.Context, userID, name string) (string, error)
CreateCharacter mocks base method.
func (*MockCharacterServiceInterface) EXPECT ¶
func (m *MockCharacterServiceInterface) EXPECT() *MockCharacterServiceInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockCharacterServiceInterface) GetCharacter ¶
GetCharacter mocks base method.
func (*MockCharacterServiceInterface) ListCharacters ¶
func (m *MockCharacterServiceInterface) ListCharacters(ctx context.Context, userID string) ([]any, error)
ListCharacters mocks base method.
func (*MockCharacterServiceInterface) MoveCharacter ¶
func (m *MockCharacterServiceInterface) MoveCharacter(ctx context.Context, characterID string, x, y int32) error
MoveCharacter mocks base method.
type MockCharacterServiceInterfaceMockRecorder ¶
type MockCharacterServiceInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockCharacterServiceInterfaceMockRecorder is the mock recorder for MockCharacterServiceInterface.
func (*MockCharacterServiceInterfaceMockRecorder) CreateCharacter ¶
func (mr *MockCharacterServiceInterfaceMockRecorder) CreateCharacter(ctx, userID, name any) *gomock.Call
CreateCharacter indicates an expected call of CreateCharacter.
func (*MockCharacterServiceInterfaceMockRecorder) GetCharacter ¶
func (mr *MockCharacterServiceInterfaceMockRecorder) GetCharacter(ctx, id any) *gomock.Call
GetCharacter indicates an expected call of GetCharacter.
func (*MockCharacterServiceInterfaceMockRecorder) ListCharacters ¶
func (mr *MockCharacterServiceInterfaceMockRecorder) ListCharacters(ctx, userID any) *gomock.Call
ListCharacters indicates an expected call of ListCharacters.
func (*MockCharacterServiceInterfaceMockRecorder) MoveCharacter ¶
func (mr *MockCharacterServiceInterfaceMockRecorder) MoveCharacter(ctx, characterID, x, y any) *gomock.Call
MoveCharacter indicates an expected call of MoveCharacter.
type MockChunkServiceInterface ¶
type MockChunkServiceInterface struct {
// contains filtered or unexported fields
}
MockChunkServiceInterface is a mock of ChunkServiceInterface interface.
func NewMockChunkServiceInterface ¶
func NewMockChunkServiceInterface(ctrl *gomock.Controller) *MockChunkServiceInterface
NewMockChunkServiceInterface creates a new mock instance.
func (*MockChunkServiceInterface) EXPECT ¶
func (m *MockChunkServiceInterface) EXPECT() *MockChunkServiceInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockChunkServiceInterface) GenerateChunk ¶
func (m *MockChunkServiceInterface) GenerateChunk(ctx context.Context, worldID string, x, y int32) (any, error)
GenerateChunk mocks base method.
type MockChunkServiceInterfaceMockRecorder ¶
type MockChunkServiceInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockChunkServiceInterfaceMockRecorder is the mock recorder for MockChunkServiceInterface.
func (*MockChunkServiceInterfaceMockRecorder) GenerateChunk ¶
func (mr *MockChunkServiceInterfaceMockRecorder) GenerateChunk(ctx, worldID, x, y any) *gomock.Call
GenerateChunk indicates an expected call of GenerateChunk.
type MockWorldServiceInterface ¶
type MockWorldServiceInterface struct {
// contains filtered or unexported fields
}
MockWorldServiceInterface is a mock of WorldServiceInterface interface.
func NewMockWorldServiceInterface ¶
func NewMockWorldServiceInterface(ctrl *gomock.Controller) *MockWorldServiceInterface
NewMockWorldServiceInterface creates a new mock instance.
func (*MockWorldServiceInterface) CreateWorld ¶
func (m *MockWorldServiceInterface) CreateWorld(ctx context.Context, name string, seed int64) (string, error)
CreateWorld mocks base method.
func (*MockWorldServiceInterface) EXPECT ¶
func (m *MockWorldServiceInterface) EXPECT() *MockWorldServiceInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockWorldServiceInterfaceMockRecorder ¶
type MockWorldServiceInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockWorldServiceInterfaceMockRecorder is the mock recorder for MockWorldServiceInterface.
func (*MockWorldServiceInterfaceMockRecorder) CreateWorld ¶
func (mr *MockWorldServiceInterfaceMockRecorder) CreateWorld(ctx, name, seed any) *gomock.Call
CreateWorld indicates an expected call of CreateWorld.